summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcombobox_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcombobox_imp.h')
-rw-r--r--kjsembed/qtbindings/qcombobox_imp.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kjsembed/qtbindings/qcombobox_imp.h b/kjsembed/qtbindings/qcombobox_imp.h
index a11fba7c..f625e73b 100644
--- a/kjsembed/qtbindings/qcombobox_imp.h
+++ b/kjsembed/qtbindings/qcombobox_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQComboBox;
+class TTQComboBox;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQComboBox;
namespace KJSEmbed {
/**
* Wrapper class for TQComboBox methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QComboBoxImp : public JSProxyImp
+class TQComboBoxImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -83,8 +83,8 @@ public:
Method_Last = -1
};
- QComboBoxImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QComboBoxImp();
+ TQComboBoxImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQComboBoxImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -98,14 +98,14 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQComboBox *toQComboBox( KJS::Object &object );
+ static TTQComboBox *toTQComboBox( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QComboBox_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QComboBox_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQComboBox_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQComboBox_2( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -174,7 +174,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQComboBox *instance; // Temp
+ TTQComboBox *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQComboBox;
namespace KJSEmbed {
/**
- * Wrapper class for TQComboBox methods.
+ * Wrapper class for TTQComboBox methods.
*
* @author Richard Moore, rich@kde.org